LaplacianNormalization

Enum LaplacianNormalization 

pub enum LaplacianNormalization {
    Unnormalized,
    Symmetric,
    Left,
    Right,
}
Normalization of the Laplacian matrix (igraph_laplacian_normalization_t), used by Graph::get_laplacian, Graph::get_laplacian_sparse and Graph::get_laplacian_sparsemat.

A is the (possibly weighted) adjacency matrix and D the diagonal matrix of degrees (or strengths, if weighted); out-, in- or total degrees are used according to the mode argument.

Variants



Unnormalized

Unnormalized Laplacian, L = D - A.



Symmetric

Symmetrically normalized Laplacian, L = I - D^(-1/2) A D^(-1/2).



Left

Left-stochastic normalized Laplacian, L = I - D^-1 A (rows sum to zero when D holds the row sums of A, e.g. out-degrees).



Right

Right-stochastic normalized Laplacian, L = I - A D^-1 (columns sum to zero when D holds the column sums of A, e.g. in-degrees).